@@ -1,8 +1,10 @@
 
-require 'zentest_mapping'
-
 $stdlib = {}
-ObjectSpace.each_object(Module) { |m| $stdlib[m.name] = true }
+ObjectSpace.each_object(Module) do |m|
+  $stdlib[m.name] = true if m.respond_to? :name
+end
+
+require 'zentest_mapping'
 
 $:.unshift( *$I.split(/:/) ) if defined? $I and String === $I
 $r = false unless defined? $r # reverse mapping for testclass names
@@ -17,17 +19,12 @@ if $r then
   require f if test ?f, f
 end
 
-$ZENTEST = true
 $TESTING = true
 
-require 'test/unit/testcase' # helps required modules
-
 class Module
-
   def zentest
     at_exit { ZenTest.autotest(self) }
   end
-
 end
 
 ##
@@ -56,7 +53,7 @@ end
 
 class ZenTest
 
-  VERSION = '3.11.1'
+  VERSION = '4.1.4'
 
   include ZenTestMapping
 
@@ -120,7 +117,7 @@ class ZenTest
   end
 
   # Get the public instance, class and singleton methods for
-  # class klass. If full is true, include the methods from 
+  # class klass. If full is true, include the methods from
   # Kernel and other modules that get included.  The methods
   # suite, new, pretty_print, pretty_print_cycle will not
   # be included in the resuting array.
@@ -207,7 +204,7 @@ class ZenTest
     return name
   end
 
-  # Does all the work of finding a class by name, 
+  # Does all the work of finding a class by name,
   # obtaining its methods and those of its superclass.
   # The full parameter determines if all the methods
   # including those of Object and mixed in modules
@@ -422,7 +419,7 @@ class ZenTest
     end # @klasses[klassname]
   end
 
-  def test_to_normal(name, klassname=nil)
+  def test_to_normal(_name, klassname=nil)
     super do |name|
       if defined? @inherited_methods then
         known_methods = (@inherited_methods[klassname] || {}).keys.sort.reverse
@@ -449,7 +446,7 @@ class ZenTest
     meth.push indentunit*indent + "end"
     return meth
   end
-   
+
   # Walk each known class and test that each method has
   # a test method
   # Then do it in the other direction...
@@ -479,7 +476,8 @@ class ZenTest
 
     if @missing_methods.size > 0 then
       @result.push ""
-      @result.push "require 'test/unit' unless defined? $ZENTEST and $ZENTEST"
+      @result.push "require 'test/unit/testcase'"
+      @result.push "require 'test/unit' if $0 == __FILE__"
       @result.push ""
     end
 
